<?php

namespace CADSUP\Services;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\Util\QuerySelector;

class RegiaoService {

    protected $connection;
    protected $cadSupUtil;
    
    public function __construct($entityManager, $environment, $cadSupUtil){
        $this->connection = $entityManager->getConnection();
        $this->environment = $environment;
        $this->cadSupUtil = $cadSupUtil;
    }
    
    public function deleteRegiao ($row){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
		$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $queryorcl = "DELETE REGIAO WHERE CDREGIAO = :P_CDREGIAO";
        $querypost = "DELETE FROM REGIAO WHERE CDREGIAO = :P_CDREGIAO;";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteFilial ($row){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
    	$queryorcl = "UPDATE FILIAL SET CDREGIAO = null WHERE CDREGIAO = :P_CDREGIAO";
    	$querypost = "UPDATE FILIAL SET CDREGIAO = null WHERE CDREGIAO = :P_CDREGIAO;";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function deleteMunicipio ($row){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
    	$queryorcl = "UPDATE MUNICIPIO SET CDREGIAO = '' WHERE CDREGIAO = :P_CDREGIAO";
    	$querypost = "UPDATE MUNICIPIO SET CDREGIAO = '' WHERE CDREGIAO = :P_CDREGIAO;";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    public function insertMunicipio ($row){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $param['P_CDPAIS']   = $row['CDPAIS'];
        $param['P_SGESTADO'] = $row['SGESTADO'];
        $param['P_CDMUNICIPIO'] = $row['CDMUNICIPIO'];
    	$queryorcl = "UPDATE MUNICIPIO SET CDREGIAO = :P_CDREGIAO WHERE CDPAIS = :P_CDPAIS AND SGESTADO = :P_SGESTADO AND CDMUNICIPIO = :P_CDMUNICIPIO";
		$querypost = "UPDATE MUNICIPIO SET CDREGIAO = :P_CDREGIAO WHERE CDPAIS = :P_CDPAIS AND SGESTADO = :P_SGESTADO AND CDMUNICIPIO = :P_CDMUNICIPIO;";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
        } catch (Exception $e){
            throw $e;
        }
    }
    
    
    public function verificaFilial ($row){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$param = array();
        $param['P_CDREGIAO'] = $row['CDREGIAO'];
        $this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->insertLista($row['CDFILIAL']);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        $param['P_CDFILIAL'] = $row['CDFILIAL'];
        $param['P_TCDREGIAO'] = $row['TCDREGIAO'];
        
    
		$queryorcl = "SELECT FILIAL.CDREGIAO, FILIAL.CDFILIAL, FILIAL.NMFILIAL, REGIAO.NMREGIAO FROM REGIAO RIGHT JOIN FILIAL ON FILIAL.CDREGIAO = REGIAO.CDREGIAO WHERE ( VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0 ) AND ( FILIAL.CDREGIAO = :P_CDREGIAO OR :P_TCDREGIAO = 'T' )";
		$querypost = "SELECT FILIAL.CDREGIAO, FILIAL.CDFILIAL, FILIAL.NMFILIAL, REGIAO.NMREGIAO FROM REGIAO RIGHT JOIN FILIAL ON FILIAL.CDREGIAO = REGIAO.CDREGIAO WHERE VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0 AND (FILIAL.CDREGIAO = :P_CDREGIAO OR :P_TCDREGIAO = 'T');";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $retorno = $std->fetchAll();
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
            return $retorno;
        } catch (Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function cadastraUnidadeNaRegiao($row) {
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
        $this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->insertLista($row['CDFILIAL']);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        $row['NRORG'] = $this->environment->getNrOrg();
        $param = array(
            'P_CDREGIAO' => $row['CDREGIAO'],
            'P_CDFILIAL' => $row['CDFILIAL'],
            'P_NRORG' => $row['NRORG']

        );
        $queryorcl = "UPDATE 
                        FILIAL
                    SET
                        CDREGIAO = :P_CDREGIAO
                    WHERE
                        (VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0)
                    AND (NRORG = :P_NRORG)";
    
        $querypost = "UPDATE FILIAL
                        SET CDREGIAO = :P_CDREGIAO
                        WHERE
                        VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0
                        AND NRORG = :P_NRORG;
                    ";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
        try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
        } catch (Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function deleteUnidade($cdfilial){
        $connection = InstanceManager::getInstance()->getService('entityManager')->getConnection();
    	$this->connection->beginTransaction();
        $codUnidade = $this->cadSupUtil->insertLista($cdfilial);
        $row['CDFILIAL'] = "_NRLISTA=".$codUnidade ;
        
        $param = array(
            'P_CDFILIAL' => $row['CDFILIAL']
        );
        
    	$queryorcl = "UPDATE FILIAL SET CDREGIAO = null WHERE (VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0)";
    	$querypost = "UPDATE FILIAL SET CDREGIAO = NULL WHERE VALOR_NA_LISTA(FILIAL.CDFILIAL, :P_CDFILIAL) <> 0;";
        $arrayQueries = array (
            'default'   => $queryorcl,
            'pdo_pgsql' => $querypost
        );
        $query = QuerySelector::getQueryByDriver($connection, $arrayQueries);
		try {
            $std = $this->connection->prepare($query);
            $std->execute($param);
            $this->cadSupUtil->deleteLista($codUnidade);
            $this->connection->commit();
        } catch (Exception $e){
            $this->connection->rollback();
            throw $e;
        }
    }
}